@@ -2,16 +2,16 @@ import os,django
 from django.conf import settings
 # 加载django配置
 current_dir=os.getcwd()
-if "/" in current_dir:
-    setting_model_str=current_dir.split("/")[-1]+".settings"
-else:
-    setting_model_str=current_dir.split("\\")[-1]+".settings"
+setting_model_str=current_dir.split("\\")[-1]+".settings"
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", setting_model_str)
 django.setup()
 # your imports, e.g. Django models
 from c_mssql import DB_Config
 from c_mssql.mssql_conn import Mssql_Conn
 
+import io,json,os
+
+
 
 
 def add_sql_description(table_name,description,column_name=None):
@@ -68,7 +68,7 @@ def update_MS_Description(models,modelname="project.models"):
     for key in dir(models):
         model=getattr(models,key)
         try:
-            if model.__module__==modelname:
+            if type(model)==django.db.models.base.ModelBase:
                 model_name=key
                 model=model
                 table_name=model._meta.db_table
